@@ -9,8 +9,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.EC2InstanceConnect 1.22.0\nVersion:        "
-        " 1.22.0.post1\nBuilder version: 7.5.9\nDocs:           "
+        "Type annotations for boto3.EC2InstanceConnect 1.23.0\nVersion:         1.23.0\nBuilder"
+        " version: 7.5.14\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect//\nBoto3 docs:"
         "     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2-instance-connect.html#EC2InstanceConnect\nOther"
@@ -23,7 +23,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.22.0.post1")
+    print("1.23.0")
 
 
 def main() -> None:
